ISA is the International Standard Atmosphere.

* `isa_table` is the layer-by-layer temperature table associated with the ISA. It was pulled from https://en.wikipedia.org/wiki/International_Standard_Atmosphere
* `isa_sample_values` contains sample atmosphere data drawn from the ISA. This data was pulled from the ISA data table at:
	https://www.engineeringtoolbox.com/international-standard-atmosphere-d_985.html

Date retrieved: Jan. 31, 2021.